# Skills Network Python Library

A library for working with [Skills Network](https://skills.network) Python labs.

 - [Documentation](https://ibm-skills-network.github.io/skillsnetwork-python-library/)

### Environment Variables

(Required environment variables for testing)

- `CV_STUDIO_TOKEN`
- `CV_STUDIO_BASE_URL`
- `IBMCLOUD_API_KEY`

## Contributing
Please see [CONTRIBUTING.md](https://github.com/ibm-skills-network/skillsnetwork-python-library/blob/main/CONTRIBUTING.md)
